# This file is generated by objective.metadata
#
# Last update: Thu Aug  5 09:34:13 2021
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a


else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$$"""
enums = """$$"""
misc.update(
    {
        "_METRICS_SIGNPOST_TYPE_TOKEN": b"signpost:metrics",
        "_MXSIGNPOST_METRICS_SNAPSHOT_FORMAT": b"\n%{public, signpost:metrics}@",
    }
)
functions = {"_MXSignpostMetricsSnapshot": (b"^v",)}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"MXMetricPayload",
        b"includesMultipleApplicationVersions",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"NSObject",
        b"didReceiveDiagnosticPayloads:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"didReceiveMetricPayloads:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE
